## Something for teleport
---

- author: Xie Haobo

- files
  delete_hosts: the list of hosts you want to delete
  teleport.csv: the list of hosts you want to alloc

- tips:
```python
    python run.py -h
    Usage: run.py -d [-a]
